@@ -11,12 +11,12 @@ alias yq='/usr/bin/yq'
 RUN_AS_CONTAINER=${RUN_AS_CONTAINER:-false}
 
 # Profile version used by init-cfg-bundle function
-CMS_PROFILE_VERSION="11.0.5"
-COMMON_PROFILE_VERSION="11.0.5"
-CT_PROFILE_VERSION="11.0.5"
-ES_PROFILE_VERSION="11.0.5"
-DB_PROFILE_VERSION="11.0.5"
-ETCD_PROFILE_VERSION="11.0.5"
+CMS_PROFILE_VERSION="11.0.6"
+COMMON_PROFILE_VERSION="11.0.6"
+CT_PROFILE_VERSION="11.0.6"
+ES_PROFILE_VERSION="11.0.6"
+DB_PROFILE_VERSION="11.0.6"
+ETCD_PROFILE_VERSION="11.0.6"
 
 # Profiles mapping
 declare -A PROFILES
@@ -116,7 +116,7 @@ ALLOW_CREATE_NODE_LABEL=$(get_parameter_value allow_create_node_label true)
 
 K8S_CLUSTER_DOMAIN=$(get_parameter_value k8s_cluster_domain "cluster.local")
 DEV_MODE=$(get_parameter_value dev_mode)
-
+MEDIAFIRST_INTEGRATION=$(get_parameter_value mediafirst_integration)
 # Since USE_SPOT_VM will be used in common function from load_cms_charts,
 # need to init USE_SPOT_VM with false.
 # The values will be later set for Azure deployment based on value passed from cms.var.
@@ -328,6 +328,7 @@ start_information_print(){
   echo "  CLUSTER_ROLE=$CLUSTER_ROLE"|& tee -i -a $LOG
   echo "  INTERNAL_CT_ENABLED=$INTERNAL_CT_ENABLED"|& tee -i -a $LOG
   echo "  DEV_MODE=$DEV_MODE"|& tee -i -a $LOG
+  echo "  MEDIAFIRST_INTEGRATION=$MEDIAFIRST_INTEGRATION"|& tee -i -a $LOG
   echo "  EXT_WHITE_LIST=$EXT_WHITE_LIST"|& tee -i -a $LOG
   if [[ $CLOUDPLATFORM == "" ]];then
   echo "  IMAGE_REGISTRY=$IMAGE_REGISTRY"|& tee -i -a $LOG
